# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'AccessConfigurationPermissionPolicy',
    'DirectoryLoginPreference',
    'DirectoryMfaAuthenticationSettingInfo',
    'DirectoryPasswordPolicy',
    'DirectorySamlIdentityProviderConfiguration',
    'DirectorySamlServiceProvider',
    'DirectoryUserProvisioningConfiguration',
    'GetAccessAssignmentsAssignmentResult',
    'GetAccessConfigurationsConfigurationResult',
    'GetAccessConfigurationsConfigurationPermissionPolicyResult',
    'GetDirectoriesDirectoryResult',
    'GetDirectoriesDirectorySamlIdentityProviderConfigurationResult',
    'GetDirectoriesDirectoryTaskResult',
    'GetGroupsGroupResult',
    'GetScimServerCredentialsCredentialResult',
    'GetUsersUserResult',
    'GetUsersUserMfaDeviceResult',
]

@pulumi.output_type
class AccessConfigurationPermissionPolicy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "permissionPolicyName":
            suggest = "permission_policy_name"
        elif key == "permissionPolicyType":
            suggest = "permission_policy_type"
        elif key == "permissionPolicyDocument":
            suggest = "permission_policy_document"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AccessConfigurationPermissionPolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AccessConfigurationPermissionPolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AccessConfigurationPermissionPolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 permission_policy_name: builtins.str,
                 permission_policy_type: builtins.str,
                 permission_policy_document: Optional[builtins.str] = None):
        """
        :param builtins.str permission_policy_name: The name of the policy.
        :param builtins.str permission_policy_type: The type of the policy. Valid values: `System`, `Inline`.
        :param builtins.str permission_policy_document: The configurations of the inline policy. **NOTE:** If `permission_policy_type` is set to `Inline`, `permission_policy_document` is required.
        """
        pulumi.set(__self__, "permission_policy_name", permission_policy_name)
        pulumi.set(__self__, "permission_policy_type", permission_policy_type)
        if permission_policy_document is not None:
            pulumi.set(__self__, "permission_policy_document", permission_policy_document)

    @property
    @pulumi.getter(name="permissionPolicyName")
    def permission_policy_name(self) -> builtins.str:
        """
        The name of the policy.
        """
        return pulumi.get(self, "permission_policy_name")

    @property
    @pulumi.getter(name="permissionPolicyType")
    def permission_policy_type(self) -> builtins.str:
        """
        The type of the policy. Valid values: `System`, `Inline`.
        """
        return pulumi.get(self, "permission_policy_type")

    @property
    @pulumi.getter(name="permissionPolicyDocument")
    def permission_policy_document(self) -> Optional[builtins.str]:
        """
        The configurations of the inline policy. **NOTE:** If `permission_policy_type` is set to `Inline`, `permission_policy_document` is required.
        """
        return pulumi.get(self, "permission_policy_document")


@pulumi.output_type
class DirectoryLoginPreference(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allowUserToGetCredentials":
            suggest = "allow_user_to_get_credentials"
        elif key == "loginNetworkMasks":
            suggest = "login_network_masks"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DirectoryLoginPreference. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DirectoryLoginPreference.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DirectoryLoginPreference.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allow_user_to_get_credentials: Optional[builtins.bool] = None,
                 login_network_masks: Optional[builtins.str] = None):
        """
        :param builtins.bool allow_user_to_get_credentials: Whether the user can obtain the program access credential in the portal after logging in.
        :param builtins.str login_network_masks: IP address whitelist
        """
        if allow_user_to_get_credentials is not None:
            pulumi.set(__self__, "allow_user_to_get_credentials", allow_user_to_get_credentials)
        if login_network_masks is not None:
            pulumi.set(__self__, "login_network_masks", login_network_masks)

    @property
    @pulumi.getter(name="allowUserToGetCredentials")
    def allow_user_to_get_credentials(self) -> Optional[builtins.bool]:
        """
        Whether the user can obtain the program access credential in the portal after logging in.
        """
        return pulumi.get(self, "allow_user_to_get_credentials")

    @property
    @pulumi.getter(name="loginNetworkMasks")
    def login_network_masks(self) -> Optional[builtins.str]:
        """
        IP address whitelist
        """
        return pulumi.get(self, "login_network_masks")


@pulumi.output_type
class DirectoryMfaAuthenticationSettingInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "mfaAuthenticationAdvanceSettings":
            suggest = "mfa_authentication_advance_settings"
        elif key == "operationForRiskLogin":
            suggest = "operation_for_risk_login"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DirectoryMfaAuthenticationSettingInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DirectoryMfaAuthenticationSettingInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DirectoryMfaAuthenticationSettingInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 mfa_authentication_advance_settings: Optional[builtins.str] = None,
                 operation_for_risk_login: Optional[builtins.str] = None):
        """
        :param builtins.str mfa_authentication_advance_settings: Global MFA validation policy
        :param builtins.str operation_for_risk_login: MFA verification policy for abnormal logon.
        """
        if mfa_authentication_advance_settings is not None:
            pulumi.set(__self__, "mfa_authentication_advance_settings", mfa_authentication_advance_settings)
        if operation_for_risk_login is not None:
            pulumi.set(__self__, "operation_for_risk_login", operation_for_risk_login)

    @property
    @pulumi.getter(name="mfaAuthenticationAdvanceSettings")
    def mfa_authentication_advance_settings(self) -> Optional[builtins.str]:
        """
        Global MFA validation policy
        """
        return pulumi.get(self, "mfa_authentication_advance_settings")

    @property
    @pulumi.getter(name="operationForRiskLogin")
    def operation_for_risk_login(self) -> Optional[builtins.str]:
        """
        MFA verification policy for abnormal logon.
        """
        return pulumi.get(self, "operation_for_risk_login")


@pulumi.output_type
class DirectoryPasswordPolicy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "hardExpire":
            suggest = "hard_expire"
        elif key == "maxLoginAttempts":
            suggest = "max_login_attempts"
        elif key == "maxPasswordAge":
            suggest = "max_password_age"
        elif key == "maxPasswordLength":
            suggest = "max_password_length"
        elif key == "minPasswordDifferentChars":
            suggest = "min_password_different_chars"
        elif key == "minPasswordLength":
            suggest = "min_password_length"
        elif key == "passwordNotContainUsername":
            suggest = "password_not_contain_username"
        elif key == "passwordReusePrevention":
            suggest = "password_reuse_prevention"
        elif key == "requireLowerCaseChars":
            suggest = "require_lower_case_chars"
        elif key == "requireNumbers":
            suggest = "require_numbers"
        elif key == "requireSymbols":
            suggest = "require_symbols"
        elif key == "requireUpperCaseChars":
            suggest = "require_upper_case_chars"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DirectoryPasswordPolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DirectoryPasswordPolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DirectoryPasswordPolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 hard_expire: Optional[builtins.bool] = None,
                 max_login_attempts: Optional[builtins.int] = None,
                 max_password_age: Optional[builtins.int] = None,
                 max_password_length: Optional[builtins.int] = None,
                 min_password_different_chars: Optional[builtins.int] = None,
                 min_password_length: Optional[builtins.int] = None,
                 password_not_contain_username: Optional[builtins.bool] = None,
                 password_reuse_prevention: Optional[builtins.int] = None,
                 require_lower_case_chars: Optional[builtins.bool] = None,
                 require_numbers: Optional[builtins.bool] = None,
                 require_symbols: Optional[builtins.bool] = None,
                 require_upper_case_chars: Optional[builtins.bool] = None):
        """
        :param builtins.bool hard_expire: Whether to restrict login after Password Expiration
        :param builtins.int max_login_attempts: Number of password retries.
        :param builtins.int max_password_age: Password validity period.
        :param builtins.int max_password_length: Maximum password length.
        :param builtins.int min_password_different_chars: The minimum number of different characters in a password.
        :param builtins.int min_password_length: Minimum password length.
        :param builtins.bool password_not_contain_username: Whether the user name is not allowed in the password.
        :param builtins.int password_reuse_prevention: Historical password check policy.
        :param builtins.bool require_lower_case_chars: Whether lowercase letters are required in the password.
        :param builtins.bool require_numbers: Whether numbers are required in the password.
        :param builtins.bool require_symbols: Whether symbols are required in the password.
        :param builtins.bool require_upper_case_chars: Whether uppercase letters are required in the password.
        """
        if hard_expire is not None:
            pulumi.set(__self__, "hard_expire", hard_expire)
        if max_login_attempts is not None:
            pulumi.set(__self__, "max_login_attempts", max_login_attempts)
        if max_password_age is not None:
            pulumi.set(__self__, "max_password_age", max_password_age)
        if max_password_length is not None:
            pulumi.set(__self__, "max_password_length", max_password_length)
        if min_password_different_chars is not None:
            pulumi.set(__self__, "min_password_different_chars", min_password_different_chars)
        if min_password_length is not None:
            pulumi.set(__self__, "min_password_length", min_password_length)
        if password_not_contain_username is not None:
            pulumi.set(__self__, "password_not_contain_username", password_not_contain_username)
        if password_reuse_prevention is not None:
            pulumi.set(__self__, "password_reuse_prevention", password_reuse_prevention)
        if require_lower_case_chars is not None:
            pulumi.set(__self__, "require_lower_case_chars", require_lower_case_chars)
        if require_numbers is not None:
            pulumi.set(__self__, "require_numbers", require_numbers)
        if require_symbols is not None:
            pulumi.set(__self__, "require_symbols", require_symbols)
        if require_upper_case_chars is not None:
            pulumi.set(__self__, "require_upper_case_chars", require_upper_case_chars)

    @property
    @pulumi.getter(name="hardExpire")
    def hard_expire(self) -> Optional[builtins.bool]:
        """
        Whether to restrict login after Password Expiration
        """
        return pulumi.get(self, "hard_expire")

    @property
    @pulumi.getter(name="maxLoginAttempts")
    def max_login_attempts(self) -> Optional[builtins.int]:
        """
        Number of password retries.
        """
        return pulumi.get(self, "max_login_attempts")

    @property
    @pulumi.getter(name="maxPasswordAge")
    def max_password_age(self) -> Optional[builtins.int]:
        """
        Password validity period.
        """
        return pulumi.get(self, "max_password_age")

    @property
    @pulumi.getter(name="maxPasswordLength")
    def max_password_length(self) -> Optional[builtins.int]:
        """
        Maximum password length.
        """
        return pulumi.get(self, "max_password_length")

    @property
    @pulumi.getter(name="minPasswordDifferentChars")
    def min_password_different_chars(self) -> Optional[builtins.int]:
        """
        The minimum number of different characters in a password.
        """
        return pulumi.get(self, "min_password_different_chars")

    @property
    @pulumi.getter(name="minPasswordLength")
    def min_password_length(self) -> Optional[builtins.int]:
        """
        Minimum password length.
        """
        return pulumi.get(self, "min_password_length")

    @property
    @pulumi.getter(name="passwordNotContainUsername")
    def password_not_contain_username(self) -> Optional[builtins.bool]:
        """
        Whether the user name is not allowed in the password.
        """
        return pulumi.get(self, "password_not_contain_username")

    @property
    @pulumi.getter(name="passwordReusePrevention")
    def password_reuse_prevention(self) -> Optional[builtins.int]:
        """
        Historical password check policy.
        """
        return pulumi.get(self, "password_reuse_prevention")

    @property
    @pulumi.getter(name="requireLowerCaseChars")
    def require_lower_case_chars(self) -> Optional[builtins.bool]:
        """
        Whether lowercase letters are required in the password.
        """
        return pulumi.get(self, "require_lower_case_chars")

    @property
    @pulumi.getter(name="requireNumbers")
    def require_numbers(self) -> Optional[builtins.bool]:
        """
        Whether numbers are required in the password.
        """
        return pulumi.get(self, "require_numbers")

    @property
    @pulumi.getter(name="requireSymbols")
    def require_symbols(self) -> Optional[builtins.bool]:
        """
        Whether symbols are required in the password.
        """
        return pulumi.get(self, "require_symbols")

    @property
    @pulumi.getter(name="requireUpperCaseChars")
    def require_upper_case_chars(self) -> Optional[builtins.bool]:
        """
        Whether uppercase letters are required in the password.
        """
        return pulumi.get(self, "require_upper_case_chars")


@pulumi.output_type
class DirectorySamlIdentityProviderConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "bindingType":
            suggest = "binding_type"
        elif key == "certificateIds":
            suggest = "certificate_ids"
        elif key == "createTime":
            suggest = "create_time"
        elif key == "encodedMetadataDocument":
            suggest = "encoded_metadata_document"
        elif key == "entityId":
            suggest = "entity_id"
        elif key == "loginUrl":
            suggest = "login_url"
        elif key == "ssoStatus":
            suggest = "sso_status"
        elif key == "updateTime":
            suggest = "update_time"
        elif key == "wantRequestSigned":
            suggest = "want_request_signed"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DirectorySamlIdentityProviderConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DirectorySamlIdentityProviderConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DirectorySamlIdentityProviderConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 binding_type: Optional[builtins.str] = None,
                 certificate_ids: Optional[Sequence[builtins.str]] = None,
                 create_time: Optional[builtins.str] = None,
                 encoded_metadata_document: Optional[builtins.str] = None,
                 entity_id: Optional[builtins.str] = None,
                 login_url: Optional[builtins.str] = None,
                 sso_status: Optional[builtins.str] = None,
                 update_time: Optional[builtins.str] = None,
                 want_request_signed: Optional[builtins.bool] = None):
        """
        :param builtins.str binding_type: The Binding method for initiating a SAML request.
        :param Sequence[builtins.str] certificate_ids: Certificate ID list
        :param builtins.str create_time: CreateTime
        :param builtins.str encoded_metadata_document: EncodedMetadataDocument
        :param builtins.str entity_id: EntityId
        :param builtins.str login_url: LoginUrl
        :param builtins.str sso_status: SSOStatus
        :param builtins.str update_time: UpdateTime
        :param builtins.bool want_request_signed: SP Request whether the signature is required
        """
        if binding_type is not None:
            pulumi.set(__self__, "binding_type", binding_type)
        if certificate_ids is not None:
            pulumi.set(__self__, "certificate_ids", certificate_ids)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if encoded_metadata_document is not None:
            pulumi.set(__self__, "encoded_metadata_document", encoded_metadata_document)
        if entity_id is not None:
            pulumi.set(__self__, "entity_id", entity_id)
        if login_url is not None:
            pulumi.set(__self__, "login_url", login_url)
        if sso_status is not None:
            pulumi.set(__self__, "sso_status", sso_status)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if want_request_signed is not None:
            pulumi.set(__self__, "want_request_signed", want_request_signed)

    @property
    @pulumi.getter(name="bindingType")
    def binding_type(self) -> Optional[builtins.str]:
        """
        The Binding method for initiating a SAML request.
        """
        return pulumi.get(self, "binding_type")

    @property
    @pulumi.getter(name="certificateIds")
    def certificate_ids(self) -> Optional[Sequence[builtins.str]]:
        """
        Certificate ID list
        """
        return pulumi.get(self, "certificate_ids")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[builtins.str]:
        """
        CreateTime
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="encodedMetadataDocument")
    def encoded_metadata_document(self) -> Optional[builtins.str]:
        """
        EncodedMetadataDocument
        """
        return pulumi.get(self, "encoded_metadata_document")

    @property
    @pulumi.getter(name="entityId")
    def entity_id(self) -> Optional[builtins.str]:
        """
        EntityId
        """
        return pulumi.get(self, "entity_id")

    @property
    @pulumi.getter(name="loginUrl")
    def login_url(self) -> Optional[builtins.str]:
        """
        LoginUrl
        """
        return pulumi.get(self, "login_url")

    @property
    @pulumi.getter(name="ssoStatus")
    def sso_status(self) -> Optional[builtins.str]:
        """
        SSOStatus
        """
        return pulumi.get(self, "sso_status")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[builtins.str]:
        """
        UpdateTime
        """
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="wantRequestSigned")
    def want_request_signed(self) -> Optional[builtins.bool]:
        """
        SP Request whether the signature is required
        """
        return pulumi.get(self, "want_request_signed")


@pulumi.output_type
class DirectorySamlServiceProvider(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "acsUrl":
            suggest = "acs_url"
        elif key == "authnSignAlgo":
            suggest = "authn_sign_algo"
        elif key == "certificateType":
            suggest = "certificate_type"
        elif key == "encodedMetadataDocument":
            suggest = "encoded_metadata_document"
        elif key == "entityId":
            suggest = "entity_id"
        elif key == "supportEncryptedAssertion":
            suggest = "support_encrypted_assertion"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DirectorySamlServiceProvider. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DirectorySamlServiceProvider.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DirectorySamlServiceProvider.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 acs_url: Optional[builtins.str] = None,
                 authn_sign_algo: Optional[builtins.str] = None,
                 certificate_type: Optional[builtins.str] = None,
                 encoded_metadata_document: Optional[builtins.str] = None,
                 entity_id: Optional[builtins.str] = None,
                 support_encrypted_assertion: Optional[builtins.bool] = None):
        """
        :param builtins.str acs_url: ACS URL of SP.
        :param builtins.str authn_sign_algo: Signature algorithms supported by AuthNRequest
        :param builtins.str certificate_type: Type of certificate used for signing in the SSO process
        :param builtins.str encoded_metadata_document: SP metadata document (Base64 encoding).
        :param builtins.str entity_id: SP identity.
        :param builtins.bool support_encrypted_assertion: Whether IdP-side encryption of Assertion is supported.
        """
        if acs_url is not None:
            pulumi.set(__self__, "acs_url", acs_url)
        if authn_sign_algo is not None:
            pulumi.set(__self__, "authn_sign_algo", authn_sign_algo)
        if certificate_type is not None:
            pulumi.set(__self__, "certificate_type", certificate_type)
        if encoded_metadata_document is not None:
            pulumi.set(__self__, "encoded_metadata_document", encoded_metadata_document)
        if entity_id is not None:
            pulumi.set(__self__, "entity_id", entity_id)
        if support_encrypted_assertion is not None:
            pulumi.set(__self__, "support_encrypted_assertion", support_encrypted_assertion)

    @property
    @pulumi.getter(name="acsUrl")
    def acs_url(self) -> Optional[builtins.str]:
        """
        ACS URL of SP.
        """
        return pulumi.get(self, "acs_url")

    @property
    @pulumi.getter(name="authnSignAlgo")
    def authn_sign_algo(self) -> Optional[builtins.str]:
        """
        Signature algorithms supported by AuthNRequest
        """
        return pulumi.get(self, "authn_sign_algo")

    @property
    @pulumi.getter(name="certificateType")
    def certificate_type(self) -> Optional[builtins.str]:
        """
        Type of certificate used for signing in the SSO process
        """
        return pulumi.get(self, "certificate_type")

    @property
    @pulumi.getter(name="encodedMetadataDocument")
    def encoded_metadata_document(self) -> Optional[builtins.str]:
        """
        SP metadata document (Base64 encoding).
        """
        return pulumi.get(self, "encoded_metadata_document")

    @property
    @pulumi.getter(name="entityId")
    def entity_id(self) -> Optional[builtins.str]:
        """
        SP identity.
        """
        return pulumi.get(self, "entity_id")

    @property
    @pulumi.getter(name="supportEncryptedAssertion")
    def support_encrypted_assertion(self) -> Optional[builtins.bool]:
        """
        Whether IdP-side encryption of Assertion is supported.
        """
        return pulumi.get(self, "support_encrypted_assertion")


@pulumi.output_type
class DirectoryUserProvisioningConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "defaultLandingPage":
            suggest = "default_landing_page"
        elif key == "sessionDuration":
            suggest = "session_duration"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DirectoryUserProvisioningConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DirectoryUserProvisioningConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DirectoryUserProvisioningConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 default_landing_page: Optional[builtins.str] = None,
                 session_duration: Optional[builtins.str] = None):
        """
        :param builtins.str default_landing_page: The duration of the Session after the user logs in.
        :param builtins.str session_duration: The duration of the Session after the user logs in.
        """
        if default_landing_page is not None:
            pulumi.set(__self__, "default_landing_page", default_landing_page)
        if session_duration is not None:
            pulumi.set(__self__, "session_duration", session_duration)

    @property
    @pulumi.getter(name="defaultLandingPage")
    def default_landing_page(self) -> Optional[builtins.str]:
        """
        The duration of the Session after the user logs in.
        """
        return pulumi.get(self, "default_landing_page")

    @property
    @pulumi.getter(name="sessionDuration")
    def session_duration(self) -> Optional[builtins.str]:
        """
        The duration of the Session after the user logs in.
        """
        return pulumi.get(self, "session_duration")


@pulumi.output_type
class GetAccessAssignmentsAssignmentResult(dict):
    def __init__(__self__, *,
                 access_configuration_id: builtins.str,
                 access_configuration_name: builtins.str,
                 directory_id: builtins.str,
                 id: builtins.str,
                 principal_id: builtins.str,
                 principal_name: builtins.str,
                 principal_type: builtins.str,
                 target_id: builtins.str,
                 target_name: builtins.str,
                 target_path_name: builtins.str,
                 target_type: builtins.str):
        """
        :param builtins.str access_configuration_id: Access configuration ID.
        :param builtins.str access_configuration_name: The name of the access configuration.
        :param builtins.str directory_id: Directory ID.
        :param builtins.str id: The ID of the Access Assignment.
        :param builtins.str principal_id: The ID of the access assignment.
        :param builtins.str principal_name: Cloud SSO identity name.
        :param builtins.str principal_type: Create the identity type of the access assignment, which can be a user or a user group.
        :param builtins.str target_id: The ID of the target to create the resource range.
        :param builtins.str target_name: Task target name.
        :param builtins.str target_path_name: The path name of the task target in the resource directory.
        :param builtins.str target_type: The type of the resource range target to be accessed. Only a single RD primary account or member account can be specified in the first phase.
        """
        pulumi.set(__self__, "access_configuration_id", access_configuration_id)
        pulumi.set(__self__, "access_configuration_name", access_configuration_name)
        pulumi.set(__self__, "directory_id", directory_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "principal_id", principal_id)
        pulumi.set(__self__, "principal_name", principal_name)
        pulumi.set(__self__, "principal_type", principal_type)
        pulumi.set(__self__, "target_id", target_id)
        pulumi.set(__self__, "target_name", target_name)
        pulumi.set(__self__, "target_path_name", target_path_name)
        pulumi.set(__self__, "target_type", target_type)

    @property
    @pulumi.getter(name="accessConfigurationId")
    def access_configuration_id(self) -> builtins.str:
        """
        Access configuration ID.
        """
        return pulumi.get(self, "access_configuration_id")

    @property
    @pulumi.getter(name="accessConfigurationName")
    def access_configuration_name(self) -> builtins.str:
        """
        The name of the access configuration.
        """
        return pulumi.get(self, "access_configuration_name")

    @property
    @pulumi.getter(name="directoryId")
    def directory_id(self) -> builtins.str:
        """
        Directory ID.
        """
        return pulumi.get(self, "directory_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the Access Assignment.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> builtins.str:
        """
        The ID of the access assignment.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="principalName")
    def principal_name(self) -> builtins.str:
        """
        Cloud SSO identity name.
        """
        return pulumi.get(self, "principal_name")

    @property
    @pulumi.getter(name="principalType")
    def principal_type(self) -> builtins.str:
        """
        Create the identity type of the access assignment, which can be a user or a user group.
        """
        return pulumi.get(self, "principal_type")

    @property
    @pulumi.getter(name="targetId")
    def target_id(self) -> builtins.str:
        """
        The ID of the target to create the resource range.
        """
        return pulumi.get(self, "target_id")

    @property
    @pulumi.getter(name="targetName")
    def target_name(self) -> builtins.str:
        """
        Task target name.
        """
        return pulumi.get(self, "target_name")

    @property
    @pulumi.getter(name="targetPathName")
    def target_path_name(self) -> builtins.str:
        """
        The path name of the task target in the resource directory.
        """
        return pulumi.get(self, "target_path_name")

    @property
    @pulumi.getter(name="targetType")
    def target_type(self) -> builtins.str:
        """
        The type of the resource range target to be accessed. Only a single RD primary account or member account can be specified in the first phase.
        """
        return pulumi.get(self, "target_type")


@pulumi.output_type
class GetAccessConfigurationsConfigurationResult(dict):
    def __init__(__self__, *,
                 access_configuration_id: builtins.str,
                 access_configuration_name: builtins.str,
                 create_time: builtins.str,
                 description: builtins.str,
                 directory_id: builtins.str,
                 id: builtins.str,
                 permission_policies: Sequence['outputs.GetAccessConfigurationsConfigurationPermissionPolicyResult'],
                 relay_state: builtins.str,
                 session_duration: builtins.int,
                 status_notifications: Sequence[builtins.str]):
        """
        :param builtins.str access_configuration_id: The AccessConfigurationId of the Access Configuration.
        :param builtins.str access_configuration_name: The AccessConfigurationName of the Access Configuration.
        :param builtins.str create_time: The Created Time of the Directory.
        :param builtins.str description: The Description of the Directory.
        :param builtins.str directory_id: The ID of the Directory.
        :param builtins.str id: The ID of the Access Configuration.
        :param Sequence['GetAccessConfigurationsConfigurationPermissionPolicyArgs'] permission_policies: The Policy List.
        :param builtins.str relay_state: The RelayState of the Access Configuration.
        :param builtins.int session_duration: The SessionDuration of the Access Configuration.
        :param Sequence[builtins.str] status_notifications: The StatusNotifications of the Access Configuration.
        """
        pulumi.set(__self__, "access_configuration_id", access_configuration_id)
        pulumi.set(__self__, "access_configuration_name", access_configuration_name)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "directory_id", directory_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "permission_policies", permission_policies)
        pulumi.set(__self__, "relay_state", relay_state)
        pulumi.set(__self__, "session_duration", session_duration)
        pulumi.set(__self__, "status_notifications", status_notifications)

    @property
    @pulumi.getter(name="accessConfigurationId")
    def access_configuration_id(self) -> builtins.str:
        """
        The AccessConfigurationId of the Access Configuration.
        """
        return pulumi.get(self, "access_configuration_id")

    @property
    @pulumi.getter(name="accessConfigurationName")
    def access_configuration_name(self) -> builtins.str:
        """
        The AccessConfigurationName of the Access Configuration.
        """
        return pulumi.get(self, "access_configuration_name")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        The Created Time of the Directory.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        The Description of the Directory.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="directoryId")
    def directory_id(self) -> builtins.str:
        """
        The ID of the Directory.
        """
        return pulumi.get(self, "directory_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the Access Configuration.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="permissionPolicies")
    def permission_policies(self) -> Sequence['outputs.GetAccessConfigurationsConfigurationPermissionPolicyResult']:
        """
        The Policy List.
        """
        return pulumi.get(self, "permission_policies")

    @property
    @pulumi.getter(name="relayState")
    def relay_state(self) -> builtins.str:
        """
        The RelayState of the Access Configuration.
        """
        return pulumi.get(self, "relay_state")

    @property
    @pulumi.getter(name="sessionDuration")
    def session_duration(self) -> builtins.int:
        """
        The SessionDuration of the Access Configuration.
        """
        return pulumi.get(self, "session_duration")

    @property
    @pulumi.getter(name="statusNotifications")
    def status_notifications(self) -> Sequence[builtins.str]:
        """
        The StatusNotifications of the Access Configuration.
        """
        return pulumi.get(self, "status_notifications")


@pulumi.output_type
class GetAccessConfigurationsConfigurationPermissionPolicyResult(dict):
    def __init__(__self__, *,
                 add_time: builtins.str,
                 permission_policy_document: builtins.str,
                 permission_policy_name: builtins.str,
                 permission_policy_type: builtins.str):
        """
        :param builtins.str add_time: The Creation time of policy.
        :param builtins.str permission_policy_document: The Content of Policy.
        :param builtins.str permission_policy_name: The Policy Name of policy.
        :param builtins.str permission_policy_type: The Policy Type of policy. Valid values: `System`, `Inline`.
        """
        pulumi.set(__self__, "add_time", add_time)
        pulumi.set(__self__, "permission_policy_document", permission_policy_document)
        pulumi.set(__self__, "permission_policy_name", permission_policy_name)
        pulumi.set(__self__, "permission_policy_type", permission_policy_type)

    @property
    @pulumi.getter(name="addTime")
    def add_time(self) -> builtins.str:
        """
        The Creation time of policy.
        """
        return pulumi.get(self, "add_time")

    @property
    @pulumi.getter(name="permissionPolicyDocument")
    def permission_policy_document(self) -> builtins.str:
        """
        The Content of Policy.
        """
        return pulumi.get(self, "permission_policy_document")

    @property
    @pulumi.getter(name="permissionPolicyName")
    def permission_policy_name(self) -> builtins.str:
        """
        The Policy Name of policy.
        """
        return pulumi.get(self, "permission_policy_name")

    @property
    @pulumi.getter(name="permissionPolicyType")
    def permission_policy_type(self) -> builtins.str:
        """
        The Policy Type of policy. Valid values: `System`, `Inline`.
        """
        return pulumi.get(self, "permission_policy_type")


@pulumi.output_type
class GetDirectoriesDirectoryResult(dict):
    def __init__(__self__, *,
                 create_time: builtins.str,
                 directory_id: builtins.str,
                 directory_name: builtins.str,
                 id: builtins.str,
                 mfa_authentication_status: builtins.str,
                 region: builtins.str,
                 saml_identity_provider_configurations: Sequence['outputs.GetDirectoriesDirectorySamlIdentityProviderConfigurationResult'],
                 scim_synchronization_status: builtins.str,
                 tasks: Sequence['outputs.GetDirectoriesDirectoryTaskResult']):
        """
        :param builtins.str create_time: The CreateTime of the CloudSSO directory.
        :param builtins.str directory_id: The DirectoryId of the CloudSSO directory.
        :param builtins.str directory_name: The name of the CloudSSO directory.
        :param builtins.str id: The ID of the Directory.
        :param builtins.str mfa_authentication_status: The mfa authentication status. Valid values: `Enabled` or `Disabled`. Default to `Disabled`.
        :param builtins.str region: The Region of the CloudSSO directory.
        :param Sequence['GetDirectoriesDirectorySamlIdentityProviderConfigurationArgs'] saml_identity_provider_configurations: The saml identity provider configuration.
        :param builtins.str scim_synchronization_status: The scim synchronization status. Valid values: `Enabled` or `Disabled`. Default to `Disabled`.
        :param Sequence['GetDirectoriesDirectoryTaskArgs'] tasks: Asynchronous Task Information Array.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "directory_id", directory_id)
        pulumi.set(__self__, "directory_name", directory_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "mfa_authentication_status", mfa_authentication_status)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "saml_identity_provider_configurations", saml_identity_provider_configurations)
        pulumi.set(__self__, "scim_synchronization_status", scim_synchronization_status)
        pulumi.set(__self__, "tasks", tasks)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        The CreateTime of the CloudSSO directory.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="directoryId")
    def directory_id(self) -> builtins.str:
        """
        The DirectoryId of the CloudSSO directory.
        """
        return pulumi.get(self, "directory_id")

    @property
    @pulumi.getter(name="directoryName")
    def directory_name(self) -> builtins.str:
        """
        The name of the CloudSSO directory.
        """
        return pulumi.get(self, "directory_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the Directory.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="mfaAuthenticationStatus")
    def mfa_authentication_status(self) -> builtins.str:
        """
        The mfa authentication status. Valid values: `Enabled` or `Disabled`. Default to `Disabled`.
        """
        return pulumi.get(self, "mfa_authentication_status")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        The Region of the CloudSSO directory.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="samlIdentityProviderConfigurations")
    def saml_identity_provider_configurations(self) -> Sequence['outputs.GetDirectoriesDirectorySamlIdentityProviderConfigurationResult']:
        """
        The saml identity provider configuration.
        """
        return pulumi.get(self, "saml_identity_provider_configurations")

    @property
    @pulumi.getter(name="scimSynchronizationStatus")
    def scim_synchronization_status(self) -> builtins.str:
        """
        The scim synchronization status. Valid values: `Enabled` or `Disabled`. Default to `Disabled`.
        """
        return pulumi.get(self, "scim_synchronization_status")

    @property
    @pulumi.getter
    def tasks(self) -> Sequence['outputs.GetDirectoriesDirectoryTaskResult']:
        """
        Asynchronous Task Information Array.
        """
        return pulumi.get(self, "tasks")


@pulumi.output_type
class GetDirectoriesDirectorySamlIdentityProviderConfigurationResult(dict):
    def __init__(__self__, *,
                 create_time: builtins.str,
                 encoded_metadata_document: builtins.str,
                 entity_id: builtins.str,
                 login_url: builtins.str,
                 sso_status: builtins.str):
        """
        :param builtins.str create_time: Saml identifies the creation time of the provider configuration.
        :param builtins.str encoded_metadata_document: Base64 encoded IdP metadata document.
        :param builtins.str entity_id: SAML IdPEntityID.
        :param builtins.str login_url: SAML IdP http-post Binding address.
        :param builtins.str sso_status: SAML SSO login enabled status. Valid values: `Enabled` or `Disabled`. Default to `Disabled`.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "encoded_metadata_document", encoded_metadata_document)
        pulumi.set(__self__, "entity_id", entity_id)
        pulumi.set(__self__, "login_url", login_url)
        pulumi.set(__self__, "sso_status", sso_status)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        Saml identifies the creation time of the provider configuration.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="encodedMetadataDocument")
    def encoded_metadata_document(self) -> builtins.str:
        """
        Base64 encoded IdP metadata document.
        """
        return pulumi.get(self, "encoded_metadata_document")

    @property
    @pulumi.getter(name="entityId")
    def entity_id(self) -> builtins.str:
        """
        SAML IdPEntityID.
        """
        return pulumi.get(self, "entity_id")

    @property
    @pulumi.getter(name="loginUrl")
    def login_url(self) -> builtins.str:
        """
        SAML IdP http-post Binding address.
        """
        return pulumi.get(self, "login_url")

    @property
    @pulumi.getter(name="ssoStatus")
    def sso_status(self) -> builtins.str:
        """
        SAML SSO login enabled status. Valid values: `Enabled` or `Disabled`. Default to `Disabled`.
        """
        return pulumi.get(self, "sso_status")


@pulumi.output_type
class GetDirectoriesDirectoryTaskResult(dict):
    def __init__(__self__, *,
                 access_configuration_id: builtins.str,
                 access_configuration_name: builtins.str,
                 end_time: builtins.str,
                 failure_reason: builtins.str,
                 principal_id: builtins.str,
                 principal_name: builtins.str,
                 principal_type: builtins.str,
                 start_time: builtins.str,
                 status: builtins.str,
                 target_id: builtins.str,
                 target_name: builtins.str,
                 target_path: builtins.str,
                 target_type: builtins.str,
                 task_id: builtins.str,
                 task_type: builtins.str):
        """
        :param builtins.str access_configuration_id: The ID of Access Configuration.
        :param builtins.str access_configuration_name: The Name of Access Configuration.
        :param builtins.str end_time: The End Time of Task.
        :param builtins.str failure_reason: the Reason for the Failure of  the task.
        :param builtins.str principal_id: The ID of Cloud SSO Identity.
        :param builtins.str principal_name: The Name of Cloud SSO Identity.
        :param builtins.str principal_type: The Type of Cloud SSO Identity.
        :param builtins.str start_time: The Start Time of Task.
        :param builtins.str status: The Task Status.
        :param builtins.str target_id: The Id of deploy target.
        :param builtins.str target_name: The Name of Deploy Target.
        :param builtins.str target_path: The Path in RD of Deploy Target.
        :param builtins.str target_type: The Type of Deploy Target.
        :param builtins.str task_id: The ID of the Task.
        :param builtins.str task_type: The Type of the Task.
        """
        pulumi.set(__self__, "access_configuration_id", access_configuration_id)
        pulumi.set(__self__, "access_configuration_name", access_configuration_name)
        pulumi.set(__self__, "end_time", end_time)
        pulumi.set(__self__, "failure_reason", failure_reason)
        pulumi.set(__self__, "principal_id", principal_id)
        pulumi.set(__self__, "principal_name", principal_name)
        pulumi.set(__self__, "principal_type", principal_type)
        pulumi.set(__self__, "start_time", start_time)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "target_id", target_id)
        pulumi.set(__self__, "target_name", target_name)
        pulumi.set(__self__, "target_path", target_path)
        pulumi.set(__self__, "target_type", target_type)
        pulumi.set(__self__, "task_id", task_id)
        pulumi.set(__self__, "task_type", task_type)

    @property
    @pulumi.getter(name="accessConfigurationId")
    def access_configuration_id(self) -> builtins.str:
        """
        The ID of Access Configuration.
        """
        return pulumi.get(self, "access_configuration_id")

    @property
    @pulumi.getter(name="accessConfigurationName")
    def access_configuration_name(self) -> builtins.str:
        """
        The Name of Access Configuration.
        """
        return pulumi.get(self, "access_configuration_name")

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> builtins.str:
        """
        The End Time of Task.
        """
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter(name="failureReason")
    def failure_reason(self) -> builtins.str:
        """
        the Reason for the Failure of  the task.
        """
        return pulumi.get(self, "failure_reason")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> builtins.str:
        """
        The ID of Cloud SSO Identity.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="principalName")
    def principal_name(self) -> builtins.str:
        """
        The Name of Cloud SSO Identity.
        """
        return pulumi.get(self, "principal_name")

    @property
    @pulumi.getter(name="principalType")
    def principal_type(self) -> builtins.str:
        """
        The Type of Cloud SSO Identity.
        """
        return pulumi.get(self, "principal_type")

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> builtins.str:
        """
        The Start Time of Task.
        """
        return pulumi.get(self, "start_time")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        The Task Status.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="targetId")
    def target_id(self) -> builtins.str:
        """
        The Id of deploy target.
        """
        return pulumi.get(self, "target_id")

    @property
    @pulumi.getter(name="targetName")
    def target_name(self) -> builtins.str:
        """
        The Name of Deploy Target.
        """
        return pulumi.get(self, "target_name")

    @property
    @pulumi.getter(name="targetPath")
    def target_path(self) -> builtins.str:
        """
        The Path in RD of Deploy Target.
        """
        return pulumi.get(self, "target_path")

    @property
    @pulumi.getter(name="targetType")
    def target_type(self) -> builtins.str:
        """
        The Type of Deploy Target.
        """
        return pulumi.get(self, "target_type")

    @property
    @pulumi.getter(name="taskId")
    def task_id(self) -> builtins.str:
        """
        The ID of the Task.
        """
        return pulumi.get(self, "task_id")

    @property
    @pulumi.getter(name="taskType")
    def task_type(self) -> builtins.str:
        """
        The Type of the Task.
        """
        return pulumi.get(self, "task_type")


@pulumi.output_type
class GetGroupsGroupResult(dict):
    def __init__(__self__, *,
                 create_time: builtins.str,
                 description: builtins.str,
                 directory_id: builtins.str,
                 group_id: builtins.str,
                 group_name: builtins.str,
                 id: builtins.str,
                 provision_type: builtins.str):
        """
        :param builtins.str create_time: The Created Time of the Directory.
        :param builtins.str description: The Description of the Directory.
        :param builtins.str directory_id: The ID of the Directory.
        :param builtins.str group_id: The Group ID of the group.
        :param builtins.str group_name: The Name of the group.
        :param builtins.str id: The ID of the Group.
        :param builtins.str provision_type: The Provision Type of the Group. Valid values: `Manual`, `Synchronized`.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "directory_id", directory_id)
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "group_name", group_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "provision_type", provision_type)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        The Created Time of the Directory.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        The Description of the Directory.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="directoryId")
    def directory_id(self) -> builtins.str:
        """
        The ID of the Directory.
        """
        return pulumi.get(self, "directory_id")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> builtins.str:
        """
        The Group ID of the group.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> builtins.str:
        """
        The Name of the group.
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the Group.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="provisionType")
    def provision_type(self) -> builtins.str:
        """
        The Provision Type of the Group. Valid values: `Manual`, `Synchronized`.
        """
        return pulumi.get(self, "provision_type")


@pulumi.output_type
class GetScimServerCredentialsCredentialResult(dict):
    def __init__(__self__, *,
                 create_time: builtins.str,
                 credential_id: builtins.str,
                 credential_secret: builtins.str,
                 credential_type: builtins.str,
                 directory_id: builtins.str,
                 expire_time: builtins.str,
                 id: builtins.str,
                 status: builtins.str):
        """
        :param builtins.str create_time: The CreateTime of the resource.
        :param builtins.str credential_id: The CredentialId of the resource.
        :param builtins.str credential_secret: The CredentialSecret of the resource.
        :param builtins.str credential_type: The CredentialType of the resource.
        :param builtins.str directory_id: The ID of the Directory.
        :param builtins.str expire_time: The ExpireTime of the resource.
        :param builtins.str id: The ID of the SCIM Server Credential.
        :param builtins.str status: The Status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "credential_id", credential_id)
        pulumi.set(__self__, "credential_secret", credential_secret)
        pulumi.set(__self__, "credential_type", credential_type)
        pulumi.set(__self__, "directory_id", directory_id)
        pulumi.set(__self__, "expire_time", expire_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        The CreateTime of the resource.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="credentialId")
    def credential_id(self) -> builtins.str:
        """
        The CredentialId of the resource.
        """
        return pulumi.get(self, "credential_id")

    @property
    @pulumi.getter(name="credentialSecret")
    def credential_secret(self) -> builtins.str:
        """
        The CredentialSecret of the resource.
        """
        return pulumi.get(self, "credential_secret")

    @property
    @pulumi.getter(name="credentialType")
    def credential_type(self) -> builtins.str:
        """
        The CredentialType of the resource.
        """
        return pulumi.get(self, "credential_type")

    @property
    @pulumi.getter(name="directoryId")
    def directory_id(self) -> builtins.str:
        """
        The ID of the Directory.
        """
        return pulumi.get(self, "directory_id")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> builtins.str:
        """
        The ExpireTime of the resource.
        """
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the SCIM Server Credential.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        The Status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetUsersUserResult(dict):
    def __init__(__self__, *,
                 create_time: builtins.str,
                 description: builtins.str,
                 directory_id: builtins.str,
                 display_name: builtins.str,
                 email: builtins.str,
                 first_name: builtins.str,
                 id: builtins.str,
                 last_name: builtins.str,
                 mfa_devices: Sequence['outputs.GetUsersUserMfaDeviceResult'],
                 provision_type: builtins.str,
                 status: builtins.str,
                 user_id: builtins.str,
                 user_name: builtins.str):
        """
        :param builtins.str create_time: The create time of the user.
        :param builtins.str description: The description of user.
        :param builtins.str directory_id: The ID of the Directory.
        :param builtins.str display_name: The display name of user.
        :param builtins.str email: The User's Contact Email Address.
        :param builtins.str first_name: The first name of user.
        :param builtins.str id: The ID of the User.
        :param builtins.str last_name: The last name of user.
        :param Sequence['GetUsersUserMfaDeviceArgs'] mfa_devices: The List of MFA Device for User.
        :param builtins.str provision_type: ProvisionType.
        :param builtins.str status: User status. Valid values: `Enabled` and `Disabled`.
        :param builtins.str user_id: The User ID of the group.
        :param builtins.str user_name: The name of user.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "directory_id", directory_id)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "first_name", first_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "last_name", last_name)
        pulumi.set(__self__, "mfa_devices", mfa_devices)
        pulumi.set(__self__, "provision_type", provision_type)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "user_id", user_id)
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        The create time of the user.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        The description of user.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="directoryId")
    def directory_id(self) -> builtins.str:
        """
        The ID of the Directory.
        """
        return pulumi.get(self, "directory_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        The display name of user.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def email(self) -> builtins.str:
        """
        The User's Contact Email Address.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> builtins.str:
        """
        The first name of user.
        """
        return pulumi.get(self, "first_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the User.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> builtins.str:
        """
        The last name of user.
        """
        return pulumi.get(self, "last_name")

    @property
    @pulumi.getter(name="mfaDevices")
    def mfa_devices(self) -> Sequence['outputs.GetUsersUserMfaDeviceResult']:
        """
        The List of MFA Device for User.
        """
        return pulumi.get(self, "mfa_devices")

    @property
    @pulumi.getter(name="provisionType")
    def provision_type(self) -> builtins.str:
        """
        ProvisionType.
        """
        return pulumi.get(self, "provision_type")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        User status. Valid values: `Enabled` and `Disabled`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> builtins.str:
        """
        The User ID of the group.
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> builtins.str:
        """
        The name of user.
        """
        return pulumi.get(self, "user_name")


@pulumi.output_type
class GetUsersUserMfaDeviceResult(dict):
    def __init__(__self__, *,
                 device_id: builtins.str,
                 device_name: builtins.str,
                 device_type: builtins.str,
                 effective_time: builtins.str):
        """
        :param builtins.str device_id: The MFA Device ID.
        :param builtins.str device_name: The MFA Device Name.
        :param builtins.str device_type: The MFA Device Type.
        :param builtins.str effective_time: The Effective Time of MFA Device.
        """
        pulumi.set(__self__, "device_id", device_id)
        pulumi.set(__self__, "device_name", device_name)
        pulumi.set(__self__, "device_type", device_type)
        pulumi.set(__self__, "effective_time", effective_time)

    @property
    @pulumi.getter(name="deviceId")
    def device_id(self) -> builtins.str:
        """
        The MFA Device ID.
        """
        return pulumi.get(self, "device_id")

    @property
    @pulumi.getter(name="deviceName")
    def device_name(self) -> builtins.str:
        """
        The MFA Device Name.
        """
        return pulumi.get(self, "device_name")

    @property
    @pulumi.getter(name="deviceType")
    def device_type(self) -> builtins.str:
        """
        The MFA Device Type.
        """
        return pulumi.get(self, "device_type")

    @property
    @pulumi.getter(name="effectiveTime")
    def effective_time(self) -> builtins.str:
        """
        The Effective Time of MFA Device.
        """
        return pulumi.get(self, "effective_time")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAgentsResult',
    'AwaitableGetAgentsResult',
    'get_agents',
    'get_agents_output',
]

@pulumi.output_type
class GetAgentsResult:
    """
    A collection of values returned by getAgents.
    """
    def __init__(__self__, agent_name=None, agents=None, id=None, ids=None, name_regex=None, names=None, output_file=None, page_number=None, page_size=None):
        if agent_name and not isinstance(agent_name, str):
            raise TypeError("Expected argument 'agent_name' to be a str")
        pulumi.set(__self__, "agent_name", agent_name)
        if agents and not isinstance(agents, list):
            raise TypeError("Expected argument 'agents' to be a list")
        pulumi.set(__self__, "agents", agents)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)

    @property
    @pulumi.getter(name="agentName")
    def agent_name(self) -> builtins.str:
        """
        The agent Name.
        """
        return pulumi.get(self, "agent_name")

    @property
    @pulumi.getter
    def agents(self) -> Sequence['outputs.GetAgentsAgentResult']:
        """
        A list of availability zones. Each element contains the following attributes:
        """
        return pulumi.get(self, "agents")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of chatbot agents names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_size")


class AwaitableGetAgentsResult(GetAgentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAgentsResult(
            agent_name=self.agent_name,
            agents=self.agents,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size)


def get_agents(agent_name: Optional[builtins.str] = None,
               name_regex: Optional[builtins.str] = None,
               output_file: Optional[builtins.str] = None,
               page_number: Optional[builtins.int] = None,
               page_size: Optional[builtins.int] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAgentsResult:
    """
    This data source provides the Chatbot Agents of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.203.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    name_regex = alicloud.chatbot.get_agents(name_regex="^my-Agent")
    pulumi.export("alicloudChatbotAgentsId1", name_regex.agents[0].id)
    ```


    :param builtins.str agent_name: The name of the agent.
    :param builtins.str name_regex: A regex string to filter resulting chatbot agents by name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['agentName'] = agent_name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:chatbot/getAgents:getAgents', __args__, opts=opts, typ=GetAgentsResult).value

    return AwaitableGetAgentsResult(
        agent_name=pulumi.get(__ret__, 'agent_name'),
        agents=pulumi.get(__ret__, 'agents'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'))
def get_agents_output(agent_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      page_number: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                      page_size: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAgentsResult]:
    """
    This data source provides the Chatbot Agents of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.203.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    name_regex = alicloud.chatbot.get_agents(name_regex="^my-Agent")
    pulumi.export("alicloudChatbotAgentsId1", name_regex.agents[0].id)
    ```


    :param builtins.str agent_name: The name of the agent.
    :param builtins.str name_regex: A regex string to filter resulting chatbot agents by name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['agentName'] = agent_name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:chatbot/getAgents:getAgents', __args__, opts=opts, typ=GetAgentsResult)
    return __ret__.apply(lambda __response__: GetAgentsResult(
        agent_name=pulumi.get(__response__, 'agent_name'),
        agents=pulumi.get(__response__, 'agents'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AccessPointPosixUserArgs',
    'AccessPointPosixUserArgsDict',
    'AccessPointRootPathPermissionArgs',
    'AccessPointRootPathPermissionArgsDict',
    'FileSystemNfsAclArgs',
    'FileSystemNfsAclArgsDict',
    'FileSystemOptionsArgs',
    'FileSystemOptionsArgsDict',
    'FileSystemRecycleBinArgs',
    'FileSystemRecycleBinArgsDict',
    'FileSystemSmbAclArgs',
    'FileSystemSmbAclArgsDict',
]

MYPY = False

if not MYPY:
    class AccessPointPosixUserArgsDict(TypedDict):
        posix_group_id: NotRequired[pulumi.Input[builtins.int]]
        """
        The ID of the Posix user group.
        """
        posix_secondary_group_ids: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]
        """
        The ID of the second user group.
        """
        posix_user_id: NotRequired[pulumi.Input[builtins.int]]
        """
        The Posix user ID.
        """
elif False:
    AccessPointPosixUserArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AccessPointPosixUserArgs:
    def __init__(__self__, *,
                 posix_group_id: Optional[pulumi.Input[builtins.int]] = None,
                 posix_secondary_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 posix_user_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.int] posix_group_id: The ID of the Posix user group.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] posix_secondary_group_ids: The ID of the second user group.
        :param pulumi.Input[builtins.int] posix_user_id: The Posix user ID.
        """
        if posix_group_id is not None:
            pulumi.set(__self__, "posix_group_id", posix_group_id)
        if posix_secondary_group_ids is not None:
            pulumi.set(__self__, "posix_secondary_group_ids", posix_secondary_group_ids)
        if posix_user_id is not None:
            pulumi.set(__self__, "posix_user_id", posix_user_id)

    @property
    @pulumi.getter(name="posixGroupId")
    def posix_group_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID of the Posix user group.
        """
        return pulumi.get(self, "posix_group_id")

    @posix_group_id.setter
    def posix_group_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "posix_group_id", value)

    @property
    @pulumi.getter(name="posixSecondaryGroupIds")
    def posix_secondary_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        """
        The ID of the second user group.
        """
        return pulumi.get(self, "posix_secondary_group_ids")

    @posix_secondary_group_ids.setter
    def posix_secondary_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "posix_secondary_group_ids", value)

    @property
    @pulumi.getter(name="posixUserId")
    def posix_user_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The Posix user ID.
        """
        return pulumi.get(self, "posix_user_id")

    @posix_user_id.setter
    def posix_user_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "posix_user_id", value)


if not MYPY:
    class AccessPointRootPathPermissionArgsDict(TypedDict):
        owner_group_id: NotRequired[pulumi.Input[builtins.int]]
        """
        The ID of the primary user group.
        """
        owner_user_id: NotRequired[pulumi.Input[builtins.int]]
        """
        The owner user ID.
        """
        permission: NotRequired[pulumi.Input[builtins.str]]
        """
        POSIX permission.
        """
elif False:
    AccessPointRootPathPermissionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AccessPointRootPathPermissionArgs:
    def __init__(__self__, *,
                 owner_group_id: Optional[pulumi.Input[builtins.int]] = None,
                 owner_user_id: Optional[pulumi.Input[builtins.int]] = None,
                 permission: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.int] owner_group_id: The ID of the primary user group.
        :param pulumi.Input[builtins.int] owner_user_id: The owner user ID.
        :param pulumi.Input[builtins.str] permission: POSIX permission.
        """
        if owner_group_id is not None:
            pulumi.set(__self__, "owner_group_id", owner_group_id)
        if owner_user_id is not None:
            pulumi.set(__self__, "owner_user_id", owner_user_id)
        if permission is not None:
            pulumi.set(__self__, "permission", permission)

    @property
    @pulumi.getter(name="ownerGroupId")
    def owner_group_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID of the primary user group.
        """
        return pulumi.get(self, "owner_group_id")

    @owner_group_id.setter
    def owner_group_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "owner_group_id", value)

    @property
    @pulumi.getter(name="ownerUserId")
    def owner_user_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The owner user ID.
        """
        return pulumi.get(self, "owner_user_id")

    @owner_user_id.setter
    def owner_user_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "owner_user_id", value)

    @property
    @pulumi.getter
    def permission(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        POSIX permission.
        """
        return pulumi.get(self, "permission")

    @permission.setter
    def permission(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "permission", value)


if not MYPY:
    class FileSystemNfsAclArgsDict(TypedDict):
        enabled: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether the NFS ACL function is enabled.
        """
elif False:
    FileSystemNfsAclArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class FileSystemNfsAclArgs:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None):
        """
        :param pulumi.Input[builtins.bool] enabled: Whether the NFS ACL function is enabled.
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the NFS ACL function is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)


if not MYPY:
    class FileSystemOptionsArgsDict(TypedDict):
        enable_oplock: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether to enable the OpLock function. Value:
        - true: On.
        - false: does not turn on.

        > **NOTE:**  Description Only file systems of the SMB protocol type are supported.
        """
elif False:
    FileSystemOptionsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class FileSystemOptionsArgs:
    def __init__(__self__, *,
                 enable_oplock: Optional[pulumi.Input[builtins.bool]] = None):
        """
        :param pulumi.Input[builtins.bool] enable_oplock: Whether to enable the OpLock function. Value:
               - true: On.
               - false: does not turn on.
               
               > **NOTE:**  Description Only file systems of the SMB protocol type are supported.
        """
        if enable_oplock is not None:
            pulumi.set(__self__, "enable_oplock", enable_oplock)

    @property
    @pulumi.getter(name="enableOplock")
    def enable_oplock(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to enable the OpLock function. Value:
        - true: On.
        - false: does not turn on.

        > **NOTE:**  Description Only file systems of the SMB protocol type are supported.
        """
        return pulumi.get(self, "enable_oplock")

    @enable_oplock.setter
    def enable_oplock(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_oplock", value)


if not MYPY:
    class FileSystemRecycleBinArgsDict(TypedDict):
        enable_time: NotRequired[pulumi.Input[builtins.str]]
        """
        Recycle Bin open time
        """
        reserved_days: NotRequired[pulumi.Input[builtins.int]]
        """
        Retention time of files in the Recycle Bin. Unit: days.
        """
        secondary_size: NotRequired[pulumi.Input[builtins.int]]
        """
        Amount of low-frequency data stored in the recycle bin. Unit: Byte.
        """
        size: NotRequired[pulumi.Input[builtins.int]]
        """
        The amount of files stored in the Recycle Bin. Unit: Byte.
        """
        status: NotRequired[pulumi.Input[builtins.str]]
        """
        Recycle Bin Status
        """
elif False:
    FileSystemRecycleBinArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class FileSystemRecycleBinArgs:
    def __init__(__self__, *,
                 enable_time: Optional[pulumi.Input[builtins.str]] = None,
                 reserved_days: Optional[pulumi.Input[builtins.int]] = None,
                 secondary_size: Optional[pulumi.Input[builtins.int]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] enable_time: Recycle Bin open time
        :param pulumi.Input[builtins.int] reserved_days: Retention time of files in the Recycle Bin. Unit: days.
        :param pulumi.Input[builtins.int] secondary_size: Amount of low-frequency data stored in the recycle bin. Unit: Byte.
        :param pulumi.Input[builtins.int] size: The amount of files stored in the Recycle Bin. Unit: Byte.
        :param pulumi.Input[builtins.str] status: Recycle Bin Status
        """
        if enable_time is not None:
            pulumi.set(__self__, "enable_time", enable_time)
        if reserved_days is not None:
            pulumi.set(__self__, "reserved_days", reserved_days)
        if secondary_size is not None:
            pulumi.set(__self__, "secondary_size", secondary_size)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="enableTime")
    def enable_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Recycle Bin open time
        """
        return pulumi.get(self, "enable_time")

    @enable_time.setter
    def enable_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "enable_time", value)

    @property
    @pulumi.getter(name="reservedDays")
    def reserved_days(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Retention time of files in the Recycle Bin. Unit: days.
        """
        return pulumi.get(self, "reserved_days")

    @reserved_days.setter
    def reserved_days(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "reserved_days", value)

    @property
    @pulumi.getter(name="secondarySize")
    def secondary_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Amount of low-frequency data stored in the recycle bin. Unit: Byte.
        """
        return pulumi.get(self, "secondary_size")

    @secondary_size.setter
    def secondary_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "secondary_size", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The amount of files stored in the Recycle Bin. Unit: Byte.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Recycle Bin Status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


if not MYPY:
    class FileSystemSmbAclArgsDict(TypedDict):
        enable_anonymous_access: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether to allow anonymous access.
        - true: Allow anonymous access.
        - false (default): Anonymous access is not allowed.
        """
        enabled: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether SMB ACL is enabled
        """
        encrypt_data: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether transmission encryption is enabled.
        - true: Enables encryption in transit.
        - false (default): Transport encryption is not enabled.
        """
        home_dir_path: NotRequired[pulumi.Input[builtins.str]]
        """
        The user directory home path for each user. The file path format is as follows:
        - A forward slash (/) or backslash (\\) as a separator.
        - Each paragraph cannot contain ":|? *.
        - The length of each segment ranges from 0 to 255.
        - The total length range is 0~32767.

        For example, if the user directory is/home, the file system will automatically create A directory of/home/A when user A logs in. Skip if/home/A already exists.

        > **NOTE:**  Explain that user A needs to have the permission to create A directory, otherwise the/home/A directory cannot be created.
        """
        reject_unencrypted_access: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether to reject non-encrypted clients.
        - true: Deny non-encrypted clients.
        - false (default): Non-encrypted clients are not rejected.
        """
        super_admin_sid: NotRequired[pulumi.Input[builtins.str]]
        """
        The ID of the Super User. The ID rules are as follows:
        - Must start with S and no other letters can appear after the S at the beginning.
        - At least three dashes (-) apart.

        Such as S-1-5-22 or S-1-5-22-23.
        """
elif False:
    FileSystemSmbAclArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class FileSystemSmbAclArgs:
    def __init__(__self__, *,
                 enable_anonymous_access: Optional[pulumi.Input[builtins.bool]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 encrypt_data: Optional[pulumi.Input[builtins.bool]] = None,
                 home_dir_path: Optional[pulumi.Input[builtins.str]] = None,
                 reject_unencrypted_access: Optional[pulumi.Input[builtins.bool]] = None,
                 super_admin_sid: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.bool] enable_anonymous_access: Whether to allow anonymous access.
               - true: Allow anonymous access.
               - false (default): Anonymous access is not allowed.
        :param pulumi.Input[builtins.bool] enabled: Whether SMB ACL is enabled
        :param pulumi.Input[builtins.bool] encrypt_data: Whether transmission encryption is enabled.
               - true: Enables encryption in transit.
               - false (default): Transport encryption is not enabled.
        :param pulumi.Input[builtins.str] home_dir_path: The user directory home path for each user. The file path format is as follows:
               - A forward slash (/) or backslash (\\) as a separator.
               - Each paragraph cannot contain ":|? *.
               - The length of each segment ranges from 0 to 255.
               - The total length range is 0~32767.
               
               For example, if the user directory is/home, the file system will automatically create A directory of/home/A when user A logs in. Skip if/home/A already exists.
               
               > **NOTE:**  Explain that user A needs to have the permission to create A directory, otherwise the/home/A directory cannot be created.
        :param pulumi.Input[builtins.bool] reject_unencrypted_access: Whether to reject non-encrypted clients.
               - true: Deny non-encrypted clients.
               - false (default): Non-encrypted clients are not rejected.
        :param pulumi.Input[builtins.str] super_admin_sid: The ID of the Super User. The ID rules are as follows:
               - Must start with S and no other letters can appear after the S at the beginning.
               - At least three dashes (-) apart.
               
               Such as S-1-5-22 or S-1-5-22-23.
        """
        if enable_anonymous_access is not None:
            pulumi.set(__self__, "enable_anonymous_access", enable_anonymous_access)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if encrypt_data is not None:
            pulumi.set(__self__, "encrypt_data", encrypt_data)
        if home_dir_path is not None:
            pulumi.set(__self__, "home_dir_path", home_dir_path)
        if reject_unencrypted_access is not None:
            pulumi.set(__self__, "reject_unencrypted_access", reject_unencrypted_access)
        if super_admin_sid is not None:
            pulumi.set(__self__, "super_admin_sid", super_admin_sid)

    @property
    @pulumi.getter(name="enableAnonymousAccess")
    def enable_anonymous_access(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow anonymous access.
        - true: Allow anonymous access.
        - false (default): Anonymous access is not allowed.
        """
        return pulumi.get(self, "enable_anonymous_access")

    @enable_anonymous_access.setter
    def enable_anonymous_access(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_anonymous_access", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether SMB ACL is enabled
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="encryptData")
    def encrypt_data(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether transmission encryption is enabled.
        - true: Enables encryption in transit.
        - false (default): Transport encryption is not enabled.
        """
        return pulumi.get(self, "encrypt_data")

    @encrypt_data.setter
    def encrypt_data(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "encrypt_data", value)

    @property
    @pulumi.getter(name="homeDirPath")
    def home_dir_path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The user directory home path for each user. The file path format is as follows:
        - A forward slash (/) or backslash (\\) as a separator.
        - Each paragraph cannot contain ":|? *.
        - The length of each segment ranges from 0 to 255.
        - The total length range is 0~32767.

        For example, if the user directory is/home, the file system will automatically create A directory of/home/A when user A logs in. Skip if/home/A already exists.

        > **NOTE:**  Explain that user A needs to have the permission to create A directory, otherwise the/home/A directory cannot be created.
        """
        return pulumi.get(self, "home_dir_path")

    @home_dir_path.setter
    def home_dir_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "home_dir_path", value)

    @property
    @pulumi.getter(name="rejectUnencryptedAccess")
    def reject_unencrypted_access(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to reject non-encrypted clients.
        - true: Deny non-encrypted clients.
        - false (default): Non-encrypted clients are not rejected.
        """
        return pulumi.get(self, "reject_unencrypted_access")

    @reject_unencrypted_access.setter
    def reject_unencrypted_access(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "reject_unencrypted_access", value)

    @property
    @pulumi.getter(name="superAdminSid")
    def super_admin_sid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the Super User. The ID rules are as follows:
        - Must start with S and no other letters can appear after the S at the beginning.
        - At least three dashes (-) apart.

        Such as S-1-5-22 or S-1-5-22-23.
        """
        return pulumi.get(self, "super_admin_sid")

    @super_admin_sid.setter
    def super_admin_sid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "super_admin_sid", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDomainTxtGuidResult',
    'AwaitableGetDomainTxtGuidResult',
    'get_domain_txt_guid',
    'get_domain_txt_guid_output',
]

@pulumi.output_type
class GetDomainTxtGuidResult:
    """
    A collection of values returned by getDomainTxtGuid.
    """
    def __init__(__self__, domain_name=None, id=None, lang=None, output_file=None, rr=None, type=None, value=None):
        if domain_name and not isinstance(domain_name, str):
            raise TypeError("Expected argument 'domain_name' to be a str")
        pulumi.set(__self__, "domain_name", domain_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lang and not isinstance(lang, str):
            raise TypeError("Expected argument 'lang' to be a str")
        pulumi.set(__self__, "lang", lang)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if rr and not isinstance(rr, str):
            raise TypeError("Expected argument 'rr' to be a str")
        pulumi.set(__self__, "rr", rr)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if value and not isinstance(value, str):
            raise TypeError("Expected argument 'value' to be a str")
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> builtins.str:
        return pulumi.get(self, "domain_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def lang(self) -> Optional[builtins.str]:
        return pulumi.get(self, "lang")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def rr(self) -> builtins.str:
        """
        Host record.
        """
        return pulumi.get(self, "rr")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        Record the value.
        """
        return pulumi.get(self, "value")


class AwaitableGetDomainTxtGuidResult(GetDomainTxtGuidResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDomainTxtGuidResult(
            domain_name=self.domain_name,
            id=self.id,
            lang=self.lang,
            output_file=self.output_file,
            rr=self.rr,
            type=self.type,
            value=self.value)


def get_domain_txt_guid(domain_name: Optional[builtins.str] = None,
                        lang: Optional[builtins.str] = None,
                        output_file: Optional[builtins.str] = None,
                        type: Optional[builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDomainTxtGuidResult:
    """
    Provides the generation of txt records to realize the retrieval and verification of domain names.

    > **NOTE:** Available in v1.80.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    this = alicloud.dns.get_domain_txt_guid(domain_name="test111.abc",
        type="ADD_SUB_DOMAIN")
    pulumi.export("rr", this.rr)
    pulumi.export("value", this.value)
    ```


    :param builtins.str domain_name: Verified domain name.
    :param builtins.str lang: User language.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str type: Txt verification function. Value:`ADD_SUB_DOMAIN`, `RETRIEVAL`.
    """
    __args__ = dict()
    __args__['domainName'] = domain_name
    __args__['lang'] = lang
    __args__['outputFile'] = output_file
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:dns/getDomainTxtGuid:getDomainTxtGuid', __args__, opts=opts, typ=GetDomainTxtGuidResult).value

    return AwaitableGetDomainTxtGuidResult(
        domain_name=pulumi.get(__ret__, 'domain_name'),
        id=pulumi.get(__ret__, 'id'),
        lang=pulumi.get(__ret__, 'lang'),
        output_file=pulumi.get(__ret__, 'output_file'),
        rr=pulumi.get(__ret__, 'rr'),
        type=pulumi.get(__ret__, 'type'),
        value=pulumi.get(__ret__, 'value'))
def get_domain_txt_guid_output(domain_name: Optional[pulumi.Input[builtins.str]] = None,
                               lang: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               type: Optional[pulumi.Input[builtins.str]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDomainTxtGuidResult]:
    """
    Provides the generation of txt records to realize the retrieval and verification of domain names.

    > **NOTE:** Available in v1.80.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    this = alicloud.dns.get_domain_txt_guid(domain_name="test111.abc",
        type="ADD_SUB_DOMAIN")
    pulumi.export("rr", this.rr)
    pulumi.export("value", this.value)
    ```


    :param builtins.str domain_name: Verified domain name.
    :param builtins.str lang: User language.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str type: Txt verification function. Value:`ADD_SUB_DOMAIN`, `RETRIEVAL`.
    """
    __args__ = dict()
    __args__['domainName'] = domain_name
    __args__['lang'] = lang
    __args__['outputFile'] = output_file
    __args__['type'] = type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:dns/getDomainTxtGuid:getDomainTxtGuid', __args__, opts=opts, typ=GetDomainTxtGuidResult)
    return __ret__.apply(lambda __response__: GetDomainTxtGuidResult(
        domain_name=pulumi.get(__response__, 'domain_name'),
        id=pulumi.get(__response__, 'id'),
        lang=pulumi.get(__response__, 'lang'),
        output_file=pulumi.get(__response__, 'output_file'),
        rr=pulumi.get(__response__, 'rr'),
        type=pulumi.get(__response__, 'type'),
        value=pulumi.get(__response__, 'value')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TrafficQosAssociationArgs', 'TrafficQosAssociation']

@pulumi.input_type
class TrafficQosAssociationArgs:
    def __init__(__self__, *,
                 qos_id: pulumi.Input[builtins.str],
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a TrafficQosAssociation resource.
        :param pulumi.Input[builtins.str] qos_id: The QoS policy ID.
        :param pulumi.Input[builtins.str] instance_id: The ID of the associated instance.
        :param pulumi.Input[builtins.str] instance_type: The type of the associated instance. Value: **physical connection** physical connection.
        """
        pulumi.set(__self__, "qos_id", qos_id)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)

    @property
    @pulumi.getter(name="qosId")
    def qos_id(self) -> pulumi.Input[builtins.str]:
        """
        The QoS policy ID.
        """
        return pulumi.get(self, "qos_id")

    @qos_id.setter
    def qos_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "qos_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the associated instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the associated instance. Value: **physical connection** physical connection.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type", value)


@pulumi.input_type
class _TrafficQosAssociationState:
    def __init__(__self__, *,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 qos_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering TrafficQosAssociation resources.
        :param pulumi.Input[builtins.str] instance_id: The ID of the associated instance.
        :param pulumi.Input[builtins.str] instance_type: The type of the associated instance. Value: **physical connection** physical connection.
        :param pulumi.Input[builtins.str] qos_id: The QoS policy ID.
        :param pulumi.Input[builtins.str] status: The status of the associated instance. Value:
        """
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if qos_id is not None:
            pulumi.set(__self__, "qos_id", qos_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the associated instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the associated instance. Value: **physical connection** physical connection.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="qosId")
    def qos_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The QoS policy ID.
        """
        return pulumi.get(self, "qos_id")

    @qos_id.setter
    def qos_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "qos_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the associated instance. Value:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("alicloud:expressconnect/trafficQosAssociation:TrafficQosAssociation")
class TrafficQosAssociation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 qos_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Express Connect Traffic Qos Association resource. Express Connect QoS associated resources.

        For information about Express Connect Traffic Qos Association and how to use it, see [What is Traffic Qos Association](https://next.api.alibabacloud.com/document/Vpc/2016-04-28/ModifyExpressConnectTrafficQos).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.expressconnect.get_physical_connections(name_regex="preserved-NODELETING")
        create_qos = alicloud.expressconnect.TrafficQos("createQos",
            qos_name=name,
            qos_description="terraform-example")
        associate_qos = alicloud.expressconnect.TrafficQosAssociation("associateQos",
            instance_id=default.ids[1],
            qos_id=create_qos.id,
            instance_type="PHYSICALCONNECTION")
        ```

        ## Import

        Express Connect Traffic Qos Association can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/trafficQosAssociation:TrafficQosAssociation example <qos_id>:<instance_id>:<instance_type>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] instance_id: The ID of the associated instance.
        :param pulumi.Input[builtins.str] instance_type: The type of the associated instance. Value: **physical connection** physical connection.
        :param pulumi.Input[builtins.str] qos_id: The QoS policy ID.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TrafficQosAssociationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Express Connect Traffic Qos Association resource. Express Connect QoS associated resources.

        For information about Express Connect Traffic Qos Association and how to use it, see [What is Traffic Qos Association](https://next.api.alibabacloud.com/document/Vpc/2016-04-28/ModifyExpressConnectTrafficQos).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.expressconnect.get_physical_connections(name_regex="preserved-NODELETING")
        create_qos = alicloud.expressconnect.TrafficQos("createQos",
            qos_name=name,
            qos_description="terraform-example")
        associate_qos = alicloud.expressconnect.TrafficQosAssociation("associateQos",
            instance_id=default.ids[1],
            qos_id=create_qos.id,
            instance_type="PHYSICALCONNECTION")
        ```

        ## Import

        Express Connect Traffic Qos Association can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/trafficQosAssociation:TrafficQosAssociation example <qos_id>:<instance_id>:<instance_type>
        ```

        :param str resource_name: The name of the resource.
        :param TrafficQosAssociationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TrafficQosAssociationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 qos_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TrafficQosAssociationArgs.__new__(TrafficQosAssociationArgs)

            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["instance_type"] = instance_type
            if qos_id is None and not opts.urn:
                raise TypeError("Missing required property 'qos_id'")
            __props__.__dict__["qos_id"] = qos_id
            __props__.__dict__["status"] = None
        super(TrafficQosAssociation, __self__).__init__(
            'alicloud:expressconnect/trafficQosAssociation:TrafficQosAssociation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_type: Optional[pulumi.Input[builtins.str]] = None,
            qos_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'TrafficQosAssociation':
        """
        Get an existing TrafficQosAssociation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] instance_id: The ID of the associated instance.
        :param pulumi.Input[builtins.str] instance_type: The type of the associated instance. Value: **physical connection** physical connection.
        :param pulumi.Input[builtins.str] qos_id: The QoS policy ID.
        :param pulumi.Input[builtins.str] status: The status of the associated instance. Value:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TrafficQosAssociationState.__new__(_TrafficQosAssociationState)

        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["qos_id"] = qos_id
        __props__.__dict__["status"] = status
        return TrafficQosAssociation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the associated instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[builtins.str]:
        """
        The type of the associated instance. Value: **physical connection** physical connection.
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="qosId")
    def qos_id(self) -> pulumi.Output[builtins.str]:
        """
        The QoS policy ID.
        """
        return pulumi.get(self, "qos_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the associated instance. Value:
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetKubernetesNodePoolsResult',
    'AwaitableGetKubernetesNodePoolsResult',
    'get_kubernetes_node_pools',
    'get_kubernetes_node_pools_output',
]

@pulumi.output_type
class GetKubernetesNodePoolsResult:
    """
    A collection of values returned by getKubernetesNodePools.
    """
    def __init__(__self__, cluster_id=None, id=None, ids=None, node_pool_name=None, nodepools=None, output_file=None):
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if node_pool_name and not isinstance(node_pool_name, str):
            raise TypeError("Expected argument 'node_pool_name' to be a str")
        pulumi.set(__self__, "node_pool_name", node_pool_name)
        if nodepools and not isinstance(nodepools, list):
            raise TypeError("Expected argument 'nodepools' to be a list")
        pulumi.set(__self__, "nodepools", nodepools)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of Nodepool IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nodePoolName")
    def node_pool_name(self) -> Optional[builtins.str]:
        """
        The name of node pool.
        """
        return pulumi.get(self, "node_pool_name")

    @property
    @pulumi.getter
    def nodepools(self) -> Sequence['outputs.GetKubernetesNodePoolsNodepoolResult']:
        """
        A list of Nodepool Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "nodepools")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")


class AwaitableGetKubernetesNodePoolsResult(GetKubernetesNodePoolsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKubernetesNodePoolsResult(
            cluster_id=self.cluster_id,
            id=self.id,
            ids=self.ids,
            node_pool_name=self.node_pool_name,
            nodepools=self.nodepools,
            output_file=self.output_file)


def get_kubernetes_node_pools(cluster_id: Optional[builtins.str] = None,
                              ids: Optional[Sequence[builtins.str]] = None,
                              node_pool_name: Optional[builtins.str] = None,
                              output_file: Optional[builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKubernetesNodePoolsResult:
    """
    This data source provides Ack Nodepool available to the user.[What is Nodepool](https://next.api.alibabacloud.com/document/CS/2015-12-15/CreateClusterNodePool)

    > **NOTE:** Available since v1.246.0.


    :param builtins.str cluster_id: The id of kubernetes cluster.
    :param Sequence[builtins.str] ids: A list of Nodepool IDs.
    :param builtins.str node_pool_name: The name of node pool.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['ids'] = ids
    __args__['nodePoolName'] = node_pool_name
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cs/getKubernetesNodePools:getKubernetesNodePools', __args__, opts=opts, typ=GetKubernetesNodePoolsResult).value

    return AwaitableGetKubernetesNodePoolsResult(
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        node_pool_name=pulumi.get(__ret__, 'node_pool_name'),
        nodepools=pulumi.get(__ret__, 'nodepools'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_kubernetes_node_pools_output(cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                                     ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                     node_pool_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                     output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKubernetesNodePoolsResult]:
    """
    This data source provides Ack Nodepool available to the user.[What is Nodepool](https://next.api.alibabacloud.com/document/CS/2015-12-15/CreateClusterNodePool)

    > **NOTE:** Available since v1.246.0.


    :param builtins.str cluster_id: The id of kubernetes cluster.
    :param Sequence[builtins.str] ids: A list of Nodepool IDs.
    :param builtins.str node_pool_name: The name of node pool.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['ids'] = ids
    __args__['nodePoolName'] = node_pool_name
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cs/getKubernetesNodePools:getKubernetesNodePools', __args__, opts=opts, typ=GetKubernetesNodePoolsResult)
    return __ret__.apply(lambda __response__: GetKubernetesNodePoolsResult(
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        node_pool_name=pulumi.get(__response__, 'node_pool_name'),
        nodepools=pulumi.get(__response__, 'nodepools'),
        output_file=pulumi.get(__response__, 'output_file')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AclArgs', 'Acl']

@pulumi.input_type
class AclArgs:
    def __init__(__self__, *,
                 actions: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 decision: pulumi.Input[builtins.str],
                 instance_id: pulumi.Input[builtins.str],
                 resource_name: pulumi.Input[builtins.str],
                 resource_type: pulumi.Input[builtins.str],
                 username: pulumi.Input[builtins.str],
                 ip_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a Acl resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] actions: The type of operations that can be performed on the resource. Valid values:
               - If `resource_type` is set to `Topic`. Valid values: `Pub`, `Sub`.
               - If `resource_type` is set to `Group`. Valid values: `Sub`.
        :param pulumi.Input[builtins.str] decision: The decision result of the authorization. Valid values: `Deny`, `Allow`.
        :param pulumi.Input[builtins.str] instance_id: The instance ID.
        :param pulumi.Input[builtins.str] resource_name: The name of the resource on which you want to grant permissions.
        :param pulumi.Input[builtins.str] resource_type: The type of the resource on which you want to grant permissions. Valid values: `Group`, `Topic`.
        :param pulumi.Input[builtins.str] username: The username of the account.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ip_whitelists: The IP address whitelists.
        """
        pulumi.set(__self__, "actions", actions)
        pulumi.set(__self__, "decision", decision)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "resource_name", resource_name)
        pulumi.set(__self__, "resource_type", resource_type)
        pulumi.set(__self__, "username", username)
        if ip_whitelists is not None:
            pulumi.set(__self__, "ip_whitelists", ip_whitelists)

    @property
    @pulumi.getter
    def actions(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        The type of operations that can be performed on the resource. Valid values:
        - If `resource_type` is set to `Topic`. Valid values: `Pub`, `Sub`.
        - If `resource_type` is set to `Group`. Valid values: `Sub`.
        """
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "actions", value)

    @property
    @pulumi.getter
    def decision(self) -> pulumi.Input[builtins.str]:
        """
        The decision result of the authorization. Valid values: `Deny`, `Allow`.
        """
        return pulumi.get(self, "decision")

    @decision.setter
    def decision(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "decision", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        The instance ID.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the resource on which you want to grant permissions.
        """
        return pulumi.get(self, "resource_name")

    @resource_name.setter
    def resource_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "resource_name", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Input[builtins.str]:
        """
        The type of the resource on which you want to grant permissions. Valid values: `Group`, `Topic`.
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter
    def username(self) -> pulumi.Input[builtins.str]:
        """
        The username of the account.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter(name="ipWhitelists")
    def ip_whitelists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The IP address whitelists.
        """
        return pulumi.get(self, "ip_whitelists")

    @ip_whitelists.setter
    def ip_whitelists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ip_whitelists", value)


@pulumi.input_type
class _AclState:
    def __init__(__self__, *,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 decision: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ip_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resource_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Acl resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] actions: The type of operations that can be performed on the resource. Valid values:
               - If `resource_type` is set to `Topic`. Valid values: `Pub`, `Sub`.
               - If `resource_type` is set to `Group`. Valid values: `Sub`.
        :param pulumi.Input[builtins.str] decision: The decision result of the authorization. Valid values: `Deny`, `Allow`.
        :param pulumi.Input[builtins.str] instance_id: The instance ID.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ip_whitelists: The IP address whitelists.
        :param pulumi.Input[builtins.str] resource_name: The name of the resource on which you want to grant permissions.
        :param pulumi.Input[builtins.str] resource_type: The type of the resource on which you want to grant permissions. Valid values: `Group`, `Topic`.
        :param pulumi.Input[builtins.str] username: The username of the account.
        """
        if actions is not None:
            pulumi.set(__self__, "actions", actions)
        if decision is not None:
            pulumi.set(__self__, "decision", decision)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if ip_whitelists is not None:
            pulumi.set(__self__, "ip_whitelists", ip_whitelists)
        if resource_name is not None:
            pulumi.set(__self__, "resource_name", resource_name)
        if resource_type is not None:
            pulumi.set(__self__, "resource_type", resource_type)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def actions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The type of operations that can be performed on the resource. Valid values:
        - If `resource_type` is set to `Topic`. Valid values: `Pub`, `Sub`.
        - If `resource_type` is set to `Group`. Valid values: `Sub`.
        """
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "actions", value)

    @property
    @pulumi.getter
    def decision(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The decision result of the authorization. Valid values: `Deny`, `Allow`.
        """
        return pulumi.get(self, "decision")

    @decision.setter
    def decision(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "decision", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The instance ID.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="ipWhitelists")
    def ip_whitelists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The IP address whitelists.
        """
        return pulumi.get(self, "ip_whitelists")

    @ip_whitelists.setter
    def ip_whitelists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ip_whitelists", value)

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the resource on which you want to grant permissions.
        """
        return pulumi.get(self, "resource_name")

    @resource_name.setter
    def resource_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_name", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the resource on which you want to grant permissions. Valid values: `Group`, `Topic`.
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The username of the account.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.type_token("alicloud:rocketmq/acl:Acl")
class Acl(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 decision: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ip_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resource_name_: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a RocketMQ Acl resource.

        For information about RocketMQ Acl and how to use it, see [What is Acl](https://www.alibabacloud.com/help/en/apsaramq-for-rocketmq/cloud-message-queue-rocketmq-5-x-series/developer-reference/api-rocketmq-2022-08-01-createinstanceacl).

        > **NOTE:** Available since v1.245.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        defaultrq_dt_gm = alicloud.vpc.Network("defaultrqDtGm",
            description="1111",
            cidr_block="192.168.0.0/16",
            vpc_name="pop-example-vpc")
        defaultj_ur_t_ym = alicloud.vpc.Switch("defaultjUrTYm",
            vpc_id=defaultrq_dt_gm.id,
            zone_id="cn-hangzhou-j",
            cidr_block="192.168.0.0/24",
            vswitch_name="pop-example-vswitch")
        default_kjznvm = alicloud.rocketmq.RocketMQInstance("defaultKJZNVM",
            product_info={
                "msg_process_spec": "rmq.p2.4xlarge",
                "send_receive_ratio": 0.3,
                "message_retention_time": 70,
            },
            service_code="rmq",
            series_code="professional",
            payment_type="PayAsYouGo",
            instance_name=name,
            sub_series_code="cluster_ha",
            remark="example",
            network_info={
                "vpc_info": {
                    "vpc_id": defaultrq_dt_gm.id,
                    "vswitches": [{
                        "vswitch_id": defaultj_ur_t_ym.id,
                    }],
                },
                "internet_info": {
                    "internet_spec": "enable",
                    "flow_out_type": "payByBandwidth",
                    "flow_out_bandwidth": 5,
                },
            },
            acl_info={
                "default_vpc_auth_free": False,
                "acl_types": [
                    "default",
                    "apache_acl",
                ],
            })
        default_me_nlxe = alicloud.rocketmq.Account("defaultMeNlxe",
            account_status="ENABLE",
            instance_id=default_kjznvm.id,
            username="tfexample",
            password="123456")
        default_va0zog = alicloud.rocketmq.RocketMQTopic("defaultVA0zog",
            instance_id=default_kjznvm.id,
            message_type="NORMAL",
            topic_name="tfexample")
        default = alicloud.rocketmq.Acl("default",
            actions=[
                "Pub",
                "Sub",
            ],
            instance_id=default_kjznvm.id,
            username=default_me_nlxe.username,
            resource_name_=default_va0zog.topic_name,
            resource_type="Topic",
            decision="Deny",
            ip_whitelists=["192.168.5.5"])
        ```

        ## Import

        RocketMQ Acl can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:rocketmq/acl:Acl example <instance_id>:<username>:<resource_type>:<resource_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] actions: The type of operations that can be performed on the resource. Valid values:
               - If `resource_type` is set to `Topic`. Valid values: `Pub`, `Sub`.
               - If `resource_type` is set to `Group`. Valid values: `Sub`.
        :param pulumi.Input[builtins.str] decision: The decision result of the authorization. Valid values: `Deny`, `Allow`.
        :param pulumi.Input[builtins.str] instance_id: The instance ID.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ip_whitelists: The IP address whitelists.
        :param pulumi.Input[builtins.str] resource_name_: The name of the resource on which you want to grant permissions.
        :param pulumi.Input[builtins.str] resource_type: The type of the resource on which you want to grant permissions. Valid values: `Group`, `Topic`.
        :param pulumi.Input[builtins.str] username: The username of the account.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AclArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a RocketMQ Acl resource.

        For information about RocketMQ Acl and how to use it, see [What is Acl](https://www.alibabacloud.com/help/en/apsaramq-for-rocketmq/cloud-message-queue-rocketmq-5-x-series/developer-reference/api-rocketmq-2022-08-01-createinstanceacl).

        > **NOTE:** Available since v1.245.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        defaultrq_dt_gm = alicloud.vpc.Network("defaultrqDtGm",
            description="1111",
            cidr_block="192.168.0.0/16",
            vpc_name="pop-example-vpc")
        defaultj_ur_t_ym = alicloud.vpc.Switch("defaultjUrTYm",
            vpc_id=defaultrq_dt_gm.id,
            zone_id="cn-hangzhou-j",
            cidr_block="192.168.0.0/24",
            vswitch_name="pop-example-vswitch")
        default_kjznvm = alicloud.rocketmq.RocketMQInstance("defaultKJZNVM",
            product_info={
                "msg_process_spec": "rmq.p2.4xlarge",
                "send_receive_ratio": 0.3,
                "message_retention_time": 70,
            },
            service_code="rmq",
            series_code="professional",
            payment_type="PayAsYouGo",
            instance_name=name,
            sub_series_code="cluster_ha",
            remark="example",
            network_info={
                "vpc_info": {
                    "vpc_id": defaultrq_dt_gm.id,
                    "vswitches": [{
                        "vswitch_id": defaultj_ur_t_ym.id,
                    }],
                },
                "internet_info": {
                    "internet_spec": "enable",
                    "flow_out_type": "payByBandwidth",
                    "flow_out_bandwidth": 5,
                },
            },
            acl_info={
                "default_vpc_auth_free": False,
                "acl_types": [
                    "default",
                    "apache_acl",
                ],
            })
        default_me_nlxe = alicloud.rocketmq.Account("defaultMeNlxe",
            account_status="ENABLE",
            instance_id=default_kjznvm.id,
            username="tfexample",
            password="123456")
        default_va0zog = alicloud.rocketmq.RocketMQTopic("defaultVA0zog",
            instance_id=default_kjznvm.id,
            message_type="NORMAL",
            topic_name="tfexample")
        default = alicloud.rocketmq.Acl("default",
            actions=[
                "Pub",
                "Sub",
            ],
            instance_id=default_kjznvm.id,
            username=default_me_nlxe.username,
            resource_name_=default_va0zog.topic_name,
            resource_type="Topic",
            decision="Deny",
            ip_whitelists=["192.168.5.5"])
        ```

        ## Import

        RocketMQ Acl can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:rocketmq/acl:Acl example <instance_id>:<username>:<resource_type>:<resource_name>
        ```

        :param str resource_name: The name of the resource.
        :param AclArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AclArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 decision: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ip_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resource_name_: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AclArgs.__new__(AclArgs)

            if actions is None and not opts.urn:
                raise TypeError("Missing required property 'actions'")
            __props__.__dict__["actions"] = actions
            if decision is None and not opts.urn:
                raise TypeError("Missing required property 'decision'")
            __props__.__dict__["decision"] = decision
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["ip_whitelists"] = ip_whitelists
            if resource_name_ is None and not opts.urn:
                raise TypeError("Missing required property 'resource_name_'")
            __props__.__dict__["resource_name"] = resource_name_
            if resource_type is None and not opts.urn:
                raise TypeError("Missing required property 'resource_type'")
            __props__.__dict__["resource_type"] = resource_type
            if username is None and not opts.urn:
                raise TypeError("Missing required property 'username'")
            __props__.__dict__["username"] = username
        super(Acl, __self__).__init__(
            'alicloud:rocketmq/acl:Acl',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            actions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            decision: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            ip_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            resource_name_: Optional[pulumi.Input[builtins.str]] = None,
            resource_type: Optional[pulumi.Input[builtins.str]] = None,
            username: Optional[pulumi.Input[builtins.str]] = None) -> 'Acl':
        """
        Get an existing Acl resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] actions: The type of operations that can be performed on the resource. Valid values:
               - If `resource_type` is set to `Topic`. Valid values: `Pub`, `Sub`.
               - If `resource_type` is set to `Group`. Valid values: `Sub`.
        :param pulumi.Input[builtins.str] decision: The decision result of the authorization. Valid values: `Deny`, `Allow`.
        :param pulumi.Input[builtins.str] instance_id: The instance ID.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ip_whitelists: The IP address whitelists.
        :param pulumi.Input[builtins.str] resource_name_: The name of the resource on which you want to grant permissions.
        :param pulumi.Input[builtins.str] resource_type: The type of the resource on which you want to grant permissions. Valid values: `Group`, `Topic`.
        :param pulumi.Input[builtins.str] username: The username of the account.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AclState.__new__(_AclState)

        __props__.__dict__["actions"] = actions
        __props__.__dict__["decision"] = decision
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["ip_whitelists"] = ip_whitelists
        __props__.__dict__["resource_name"] = resource_name_
        __props__.__dict__["resource_type"] = resource_type
        __props__.__dict__["username"] = username
        return Acl(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def actions(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        The type of operations that can be performed on the resource. Valid values:
        - If `resource_type` is set to `Topic`. Valid values: `Pub`, `Sub`.
        - If `resource_type` is set to `Group`. Valid values: `Sub`.
        """
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter
    def decision(self) -> pulumi.Output[builtins.str]:
        """
        The decision result of the authorization. Valid values: `Deny`, `Allow`.
        """
        return pulumi.get(self, "decision")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        The instance ID.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="ipWhitelists")
    def ip_whitelists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        The IP address whitelists.
        """
        return pulumi.get(self, "ip_whitelists")

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the resource on which you want to grant permissions.
        """
        return pulumi.get(self, "resource_name")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Output[builtins.str]:
        """
        The type of the resource on which you want to grant permissions. Valid values: `Group`, `Topic`.
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[builtins.str]:
        """
        The username of the account.
        """
        return pulumi.get(self, "username")

